#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Biped
# send your bug reports to bugs@dotslashplay.it
###

script_version=20250629.2

PLAYIT_COMPATIBILITY_LEVEL='2.32'

GAME_ID='biped'
GAME_NAME='Biped'

ARCHIVE_BASE_1_NAME='setup_biped_2.6_(81326).exe'
ARCHIVE_BASE_1_MD5='8e9189bef236ee081f2daf8343c90a12'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1_NAME='setup_biped_2.6_(81326)-1.bin'
ARCHIVE_BASE_1_PART1_MD5='57f64fb6ad15e1c22395e662b338d2ba'
ARCHIVE_BASE_1_SIZE='4307875'
ARCHIVE_BASE_1_VERSION='2.6-gog81326'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/biped'

ARCHIVE_BASE_0_NAME='setup_biped_1.6_(39586).exe'
ARCHIVE_BASE_0_MD5='c58ee9791defa88ef1bb92ba3b2f01d2'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_biped_1.6_(39586)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='48103181d4c54a068db5eec37e10d7e5'
ARCHIVE_BASE_0_SIZE='6500000'
ARCHIVE_BASE_0_VERSION='1.6-gog39586'

UNITY3D_NAME='biped'

CONTENT_PATH_DEFAULT='.'

WINE_PERSISTENT_DIRECTORIES='
users/${USER}/AppData/LocalLow/PostmetaGamesLimited/Biped'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=libplayit2.sh
. "$PLAYIT_LIB2"

# Run the default initialization actions

initialization_default "$@"

# Extract game data

archive_extraction_default

# Include game data

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers

launchers_generation 'PKG_BIN'

# Build packages

packages_generation
print_instructions

# Clean up

working_directory_cleanup

exit 0
