#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2023 Mopi
# SPDX-FileCopyrightText: © 2025 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Lost Words: Beyond the Page
# send your bug reports to bugs@dotslashplay.it
###

script_version=20250908.1

PLAYIT_COMPATIBILITY_LEVEL='2.33'

GAME_ID='lost-words'
GAME_NAME='Lost Words: Beyond the Page'

ARCHIVE_BASE_0_NAME='setup_lost_words_beyond_the_page_release_2021-04-23_8_(64bit)_(46551).exe'
ARCHIVE_BASE_0_MD5='0c36cfe013e3196442d77a128a38aa9f'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_lost_words_beyond_the_page_release_2021-04-23_8_(64bit)_(46551)-1.bin'
ARCHIVE_BASE_0_PART1_MD5='c632a4a1f22c8f2587e1d224547f00eb'
ARCHIVE_BASE_0_SIZE='5000000'
ARCHIVE_BASE_0_VERSION='2021.04.23.8-gog46551'
ARCHIVE_BASE_0_URL='https://www.gog.com/en/game/lost_words_beyond_the_page'

UNITY3D_NAME='lost words'

CONTENT_PATH_DEFAULT='.'

WINE_PERSISTENT_DIRECTORIES='
users/${USER}/AppData/LocalLow/Fourth State/Lost Words'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=libplayit2.sh
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
