#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Tulpa
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260522.2

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='tulpa'
GAME_NAME='Tulpa'

# This game is no longer available for sale from humblebundle.com
ARCHIVE_BASE_0_NAME='Tulpa_Linux_1423847478.zip'
ARCHIVE_BASE_0_MD5='3e01614c5c1c562aaf423689a1f51df9'
ARCHIVE_BASE_0_SIZE='527248'
ARCHIVE_BASE_0_VERSION='1.0-humble150213'

UNITY3D_NAME='Tulpa'
UNITY3D_PLUGINS='
ScreenSelector.so'
# Crash on launch (after logo video) if CSteamworks is missing
UNITY3D_PLUGINS="$UNITY3D_PLUGINS
libCSteamworks.so"
# libCSteamworks.so requirements
UNITY3D_PLUGINS="$UNITY3D_PLUGINS
libsteam_api.so"

CONTENT_PATH_DEFAULT='Tulpa (Linux)'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
PKG_BIN_DEPENDENCIES_LIBRARIES='
libatk-1.0.so.0
libcairo.so.2
libc.so.6
libdl.so.2
libfontconfig.so.1
libfreetype.so.6
libgcc_s.so.1
libgdk_pixbuf-2.0.so.0
libgdk-x11-2.0.so.0
libgio-2.0.so.0
libglib-2.0.so.0
libGL.so.1
libGLU.so.1
libgmodule-2.0.so.0
libgobject-2.0.so.0
libgthread-2.0.so.0
libgtk-x11-2.0.so.0
libm.so.6
libpango-1.0.so.0
libpangocairo-1.0.so.0
libpangoft2-1.0.so.0
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXcursor.so.1
libXext.so.6
libXrandr.so.2'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Prevent inclusion of unused 32-bit Mono libraries.

rm --recursive "$(path_archive_contents)/$(unity3d_name)_Data/Mono/x86"

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

# Do not disable the MAP_32BIT flag, as it would lead to a crash on launch.
unity3d_disable_map32bit() { return 0 ; }

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
