#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2020 Hoël Bézier <hoelbezier@riseup.net>
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Sundered
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260521.2

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='sundered'
GAME_NAME='Sundered'

ARCHIVE_BASE_ITCH_0_NAME='sundered-linux.zip'
ARCHIVE_BASE_ITCH_0_MD5='1be5d771f33fa95f3a567aef75314750'
ARCHIVE_BASE_ITCH_0_SIZE='2439430'
ARCHIVE_BASE_ITCH_0_VERSION='1.0-itch.2020.06.07'
ARCHIVE_BASE_ITCH_0_URL='https://thunderlotus.itch.io/sundered'

ARCHIVE_BASE_GOG_0_NAME='sundered_20190404_29317.sh'
ARCHIVE_BASE_GOG_0_MD5='efd81d3e4b14d26cdef2362b888e0a56'
ARCHIVE_BASE_GOG_0_SIZE='2500000'
ARCHIVE_BASE_GOG_0_VERSION='20190404-gog23987'
ARCHIVE_BASE_GOG_0_URL='https://www.gog.com/game/sundered'

UNITY3D_NAME='Sundered'
UNITY3D_PLUGINS='
ScreenSelector.so'

CONTENT_PATH_DEFAULT_ITCH='linux'
CONTENT_PATH_DEFAULT_GOG='data/noarch/game'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libgdk_pixbuf-2.0.so.0
libglib-2.0.so.0
libgobject-2.0.so.0
libgtk-x11-2.0.so.0
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6
libz.so.1'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Prevent inclusion of unused 32-bit Mono libraries.

rm --recursive "$(path_archive_contents)/$(unity3d_name)_Data/Mono/x86"

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
