#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2021 Daguhh
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Shovel Knight
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260519.1

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='shovel-knight'
GAME_NAME='Shovel Knight: Treasure Trove'

ARCHIVE_BASE_0_NAME='shovel_knight_treasure_trove_4_1b_arby_s_46298.sh'
ARCHIVE_BASE_0_MD5='2f5e07e20ac615eb248ab81c25974d53'
ARCHIVE_BASE_0_SIZE='500000'
ARCHIVE_BASE_0_VERSION='4.1b-gog46298'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/shovel_knight'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_LIBS_BIN_RELATIVE_PATH='64'
# TODO: An explicit list of libraries should be set.
CONTENT_LIBS_BIN_FILES='
*'
CONTENT_GAME_BIN_RELATIVE_PATH='64'
CONTENT_GAME_BIN_FILES='
ShovelKnight'
CONTENT_GAME_DATA_FILES='
data'
# TODO: Check if these documentation files are actually related to the game itself.
CONTENT_DOC_DATA_PATH='data/noarch/docs'
CONTENT_DOC_DATA_FILES='
*.txt'

APP_MAIN_EXE='ShovelKnight'
APP_MAIN_ICON='../support/icon.png'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
# TODO: The list of required native libraries might not be complete.
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libGL.so.1
libSDL2-2.0.so.0
libstdc++.so.6'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
