#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2023 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Deadlight
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260514.1

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='deadlight'
GAME_NAME='Deadlight'

ARCHIVE_BASE_1_NAME='setup_deadlight_directors_cut_gog-2(cs)_(19167).exe'
ARCHIVE_BASE_1_MD5='70b8df3f8162cc0a9a43e531b6a723c5'
ARCHIVE_BASE_1_TYPE='innosetup'
ARCHIVE_BASE_1_PART1_NAME='setup_deadlight_directors_cut_gog-2(cs)_(19167)-1.bin'
ARCHIVE_BASE_1_PART1_MD5='6392568bcc7c4a4613e09cdbb40afafd'
ARCHIVE_BASE_1_PART2_NAME='setup_deadlight_directors_cut_gog-2(cs)_(19167)-2.bin'
ARCHIVE_BASE_1_PART2_MD5='fa080fbdd39369969be4ac54c2aa7bd2'
ARCHIVE_BASE_1_SIZE='5042824'
ARCHIVE_BASE_1_VERSION='1.0-gog19167'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/deadlight_directors_cut'

ARCHIVE_BASE_0_NAME='setup_deadlight_directors_cut_2.0.0.2.exe'
ARCHIVE_BASE_0_MD5='1a753e4f9a209de5bd916ac98b88a9b7'
ARCHIVE_BASE_0_TYPE='innosetup'
ARCHIVE_BASE_0_PART1_NAME='setup_deadlight_directors_cut_2.0.0.2-1.bin'
ARCHIVE_BASE_0_PART1_MD5='246b4684d801ea84b6490e01bcf5c659'
ARCHIVE_BASE_0_PART1_TYPE='rar'
ARCHIVE_BASE_0_PART2_NAME='setup_deadlight_directors_cut_2.0.0.2-2.bin'
ARCHIVE_BASE_0_PART2_MD5='3cb7cdd9fea50a66d7f06a6b2d0426c6'
ARCHIVE_BASE_0_SIZE='5100000'
ARCHIVE_BASE_0_VERSION='1.0-gog2.0.0.2'

GAME_ENGINE='unrealengine3'

CONTENT_PATH_DEFAULT='.'
CONTENT_PATH_DEFAULT_0='game'
# TODO: Drop unused libraries.
CONTENT_LIBS_BIN_FILES='
Binaries/Win64/APEX_ClothingCHECKED_x64.dll
Binaries/Win64/APEX_ClothingGPUCHECKED_x64.dll
Binaries/Win64/APEX_Clothing_LegacyCHECKED_x64.dll
Binaries/Win64/APEX_Common_LegacyCHECKED_x64.dll
Binaries/Win64/APEX_DestructibleCHECKED_x64.dll
Binaries/Win64/APEX_Destructible_LegacyCHECKED_x64.dll
Binaries/Win64/ApexFrameworkCHECKED_x64.dll
Binaries/Win64/APEX_Framework_LegacyCHECKED_x64.dll
Binaries/Win64/atc_api.dll
Binaries/Win64/bink2w64.dll
Binaries/Win64/cudart64_30_9.dll
Binaries/Win64/cudart64_41_22.dll
Binaries/Win64/cudart64_42_9.dll
Binaries/Win64/dbghelp.dll
Binaries/Win64/EasyHook64.dll
Binaries/Win64/FxGraphLayout_x64.dll
Binaries/Win64/GRBCHECKED_1_1_api2_x64.dll
Binaries/Win64/libogg_64.dll
Binaries/Win64/libresample_x64.dll
Binaries/Win64/libvorbis_64.dll
Binaries/Win64/libvorbisfile_64.dll
Binaries/Win64/msvcp100d.dll
Binaries/Win64/msvcp100.dll
Binaries/Win64/msvcp110d.dll
Binaries/Win64/msvcp110.dll
Binaries/Win64/msvcr100d.dll
Binaries/Win64/msvcr100.dll
Binaries/Win64/msvcr110d.dll
Binaries/Win64/msvcr110.dll
Binaries/Win64/nvtt_64.dll
Binaries/Win64/NxCharacter64.dll
Binaries/Win64/PhysXCooking64.dll
Binaries/Win64/PhysXCore64.dll
Binaries/Win64/PhysXLoader64CHECKED.dll
Binaries/Win64/PhysXLoader64.dll
Binaries/Win64/substance_linker.dll
Binaries/Win64/substance_sse2_blend.dll
Binaries/Win64/tbbmalloc_debug.dll
Binaries/Win64/tbbmalloc.dll
Binaries/Win64/tm2serverlib64.dll
Binaries/Win64/wxmsw28u_adv_vc_custom_64.dll
Binaries/Win64/wxmsw28u_aui_vc_custom_64.dll
Binaries/Win64/wxmsw28u_core_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_adv_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_aui_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_core_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_html_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_richtext_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_xml_vc_custom_64.dll
Binaries/Win64/wxmsw28ud_xrc_vc_custom_64.dll
Binaries/Win64/wxmsw28u_html_vc_custom_64.dll
Binaries/Win64/wxmsw28u_richtext_vc_custom_64.dll
Binaries/Win64/wxmsw28u_vc_custom_64.dll
Binaries/Win64/wxmsw28u_xml_vc_custom_64.dll
Binaries/Win64/wxmsw28u_xrc_vc_custom_64.dll'
# TODO: Check if the Steam library is required.
CONTENT_LIBS0_BIN_FILES='
Binaries/Win64/steam_api64.dll'
# TODO: Check if the Galaxy libraries are required.
CONTENT_LIBS0_BIN_FILES='
Binaries/Win64/Galaxy64.dll
Binaries/Win64/GalaxyPeer64.dll'
# TODO: Check if the telemetry libraries are required.
CONTENT_LIBS2_BIN_FILES='
Binaries/Win64/telemetry64.dll
Binaries/Win64/telemetry64c.dll'
CONTENT_GAME_BIN_FILES='
Engine
Binaries/Win64/LOTDGame.exe'
# The following .dll files are Mono/.Net assemblies.
CONTENT_GAME0_BIN_FILES='
Binaries/Win64/Aga.Controls.dll
Binaries/Win64/AgentInterface.dll
Binaries/Win64/DebuggerInterface.dll
Binaries/Win64/ICSharpCode.TextEditor.dll
Binaries/Win64/p4dn.dll
Binaries/Win64/UnrealDebugger.dll
Binaries/Win64/WeifenLuo.WinFormsUI.Docking.dll
Binaries/Win64/WindowsTools_x64.dll'
CONTENT_GAME_DATA_FILES='
LOTDGame'

WINE_PERSISTENT_DIRECTORIES='
users/${USER}/Documents/My Games/UnrealEngine3/LOTDGame'
WINE_WINEPREFIX_TWEAKS='mono'

APP_MAIN_EXE='Binaries/Win64/LOTDGame.exe'
# The application type must be set explicitly,
# or it would be wrongly guessed as a Mono one.
APP_MAIN_TYPE='wine'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='64'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

# Install shipped libraries.
wineprefix_init_custom() {
	cat <<- EOF
	# Install shipped libraries.
	PATH_LIBRARIES_SYSTEM='$(path_libraries)'
	EOF
	cat <<- 'EOF'
	find "$PATH_LIBRARIES_SYSTEM" -iname '*.dll' | while read -r dll_source; do
		dll_destination="${PATH_PREFIX}${dll_source#"${PATH_LIBRARIES_SYSTEM}"}"
	    mkdir --parents "$(dirname "$dll_destination")"
	    ln --symbolic --force "$dll_source" "$dll_destination"
	done
	EOF
}

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
