#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2026 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Guacamelee
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260424.1

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='guacamelee'
GAME_NAME='Guacamelee!'

# This game used to be distributed by Humble Bundle.
ARCHIVE_BASE_0_NAME='Guacamelee_DRMFREE.sh'
ARCHIVE_BASE_0_MD5='b06af932c1aaefb8f157c977061388ef'
ARCHIVE_BASE_0_SIZE='576894'
ARCHIVE_BASE_0_VERSION='1.0-humble.2023.10.12'

CONTENT_PATH_DEFAULT='data'
CONTENT_GAME_BIN_RELATIVE_PATH='x86'
CONTENT_GAME_BIN_FILES='
game-bin'
CONTENT_LIBS_BIN_RELATIVE_PATH='x86/lib32'
CONTENT_LIBS_BIN_FILES='
libfmodevent-4.44.27.so
libfmodex-4.44.27.so'
CONTENT_GAME_DATA_RELATIVE_PATH='noarch'
CONTENT_GAME_DATA_FILES='
media
level00.dat
levels.dat
misc.dat
resources.dat
shaders.dat.ogl
skin00.dat
Guacamelee.png'
CONTENT_DOC_DATA_RELATIVE_PATH='noarch'
CONTENT_DOC_DATA_FILES='
README.linux'

APP_MAIN_EXE='game-bin'
APP_MAIN_ICON='noarch/Guacamelee.png'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='32'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libGL.so.1
libm.so.6
libpthread.so.0
librt.so.1
libSDL2-2.0.so.0
libstdc++.so.6'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
