#!/bin/sh
# SPDX-License-Identifier: ACSL
# SPDX-FileCopyrightText: © 2021 Mopi
# SPDX-FileCopyrightText: © 2024 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Pinstripe
# send your bug reports to bugs@dotslashplay.it
###

script_version=20260522.2

PLAYIT_COMPATIBILITY_LEVEL='2.35'

GAME_ID='pinstripe'
GAME_NAME='Pinstripe'

ARCHIVE_BASE_0_NAME='pinstripe_en_2_0_2_21609.sh'
ARCHIVE_BASE_0_MD5='369f761e1cb1159838a2ae8f82313a92'
ARCHIVE_BASE_0_SIZE='1450210'
# 2.1.0 is the correct game version, 2_0_2 in the installer name does not mean anything.
ARCHIVE_BASE_0_VERSION='2.1.0-gog21609'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/pinstripe'

UNITY3D_NAME='Pinstripe'
UNITY3D_PLUGINS='
ScreenSelector.so'
# Crash on starting/continuing a game session if libCSteamworks.so is missing
# System.DllNotFoundException: CSteamworks
#   at (wrapper managed-to-native) Steamworks.NativeMethods:SteamAPI_RestartAppIfNecessary (Steamworks.AppId_t)
#   at Steamworks.SteamAPI.RestartAppIfNecessary (AppId_t unOwnAppID) [0x00000] in <filename unknown>:0 
#   at SteamManager.Awake () [0x00000] in <filename unknown>:0 
UNITY3D_PLUGINS="$UNITY3D_PLUGINS
libCSteamworks.so"
# libCSteamworks.so requirements
UNITY3D_PLUGINS="$UNITY3D_PLUGINS
libsteam_api.so"

CONTENT_PATH_DEFAULT='data/noarch/game'

PACKAGES_LIST='
PKG_BIN
PKG_DATA'

PKG_BIN_ARCH='32'
PKG_BIN_DEPENDENCIES_SIBLINGS='
PKG_DATA'
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libgdk_pixbuf-2.0.so.0
libglib-2.0.so.0
libGL.so.1
libgobject-2.0.so.0
libgtk-x11-2.0.so.0
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6
libX11.so.6
libXcursor.so.1
libXrandr.so.2
libz.so.1'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# Load common functions.

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_dir in \
		"$PWD" \
		"${HOME}/.local/lib/play.it" \
		'/usr/local/lib/play.it' \
		'/usr/lib/play.it'
	do
		playit_lib_path="${playit_lib_dir}/libplayit.sh.2"
		if [ -e "$playit_lib_path" ]; then
			PLAYIT_LIB2="$playit_lib_path"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit.sh.2 not found.\n'
	exit 1
fi
# shellcheck source=libplayit.sh.2
. "$PLAYIT_LIB2"

# Run default initialisation actions.

initialization_default "$@"

# Extract game data.

archive_extraction_default

# Include game data.

content_inclusion_icons 'PKG_DATA'
content_inclusion_default

# Write launchers.

launchers_generation

# Build packages.

packages_generation
print_instructions

# Clean up.

working_directory_cleanup

exit 0
